v1

package
v0.0.0-release-12.4.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2026 License: AGPL-3.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

const FullValidConfigForTesting = `{
	"token": "test", 
	"title": "test-title", 
	"description": "test-description" 
}`

FullValidConfigForTesting is a string representation of a JSON object that contains all fields supported by the notifier Config. It can be used without secrets.

const FullValidSecretsForTesting = `{
	"token": "test-secret-token"
}`

FullValidSecretsForTesting is a string representation of JSON object that contains all fields that can be overridden from secrets

const Version = schema.V1

Variables

var (
	// APIURL of where the notification payload is sent. It is public to be overridable in integration tests.
	// API document link: https://notify-bot.line.me/doc/en/
	APIURL = "https://notify-api.line.me/api/notify"
)
var Schema = schema.IntegrationSchemaVersion{
	TypeAlias: "line",
	Version:   Version,
	CanCreate: false,
	Options: []schema.Field{
		{
			Label:        "Token",
			Element:      schema.ElementTypeInput,
			InputType:    schema.InputTypeText,
			Placeholder:  "LINE notify token key",
			PropertyName: "token",
			Required:     true,
			Secure:       true,
		},
		{
			Label:        "Title",
			Element:      schema.ElementTypeTextArea,
			InputType:    schema.InputTypeText,
			Description:  "Templated title of the message",
			PropertyName: "title",
			Placeholder:  templates.DefaultMessageTitleEmbed,
		},
		{
			Label:        "Description",
			Element:      schema.ElementTypeTextArea,
			InputType:    schema.InputTypeText,
			Description:  "Templated description of the message",
			PropertyName: "description",
			Placeholder:  templates.DefaultMessageEmbed,
		},
	},
}

Functions

This section is empty.

Types

type Config

type Config struct {
	Token       string `json:"token,omitempty" yaml:"token,omitempty"`
	Title       string `json:"title,omitempty" yaml:"title,omitempty"`
	Description string `json:"description,omitempty" yaml:"description,omitempty"`
}

func NewConfig

func NewConfig(jsonData json.RawMessage, decryptFn receivers.DecryptFunc) (Config, error)

type Notifier

type Notifier struct {
	*receivers.Base
	// contains filtered or unexported fields
}

Notifier is responsible for sending alert notifications to LINE.

func New

func New(cfg Config, meta receivers.Metadata, template *templates.Template, sender receivers.WebhookSender, logger log.Logger) *Notifier

func (*Notifier) Notify

func (ln *Notifier) Notify(ctx context.Context, as ...*types.Alert) (bool, error)

Notify send an alert notification to LINE

func (*Notifier) SendResolved

func (ln *Notifier) SendResolved() bool

Jump to